@@ -1,7 +1,7 @@
 import asyncio
 import contextlib
 
-from .event import Event, EventRouter, EventRouterHost, Eventful
+from .event import Event, EventRouter, EventRouterHost
 from .util import int_to_ordinal
 
 
@@ -23,5 +23,4 @@ def aiorun(startup, cleanup):
       finally:
          loop.close()
 
-
 __all__ = ["Event", "EventRouterHost", "EventRouter", "int_to_ordinal"]
